@@ -23,10 +23,10 @@ impl<'src> Display for Setting<'src> {
       | Setting::Fallback(value)
       | Setting::IgnoreComments(value)
       | Setting::PositionalArguments(value)
-      | Setting::WindowsPowerShell(value) => write!(f, "{}", value),
-      Setting::Shell(shell) | Setting::WindowsShell(shell) => write!(f, "{}", shell),
+      | Setting::WindowsPowerShell(value) => write!(f, "{value}"),
+      Setting::Shell(shell) | Setting::WindowsShell(shell) => write!(f, "{shell}"),
       Setting::Tempdir(tempdir) => {
-        write!(f, "{:?}", tempdir)
+        write!(f, "{tempdir:?}")
       }
     }
   }
