@@ -1,12 +1,9 @@
-use super::*;
-
-use crate::compiler::Compiler;
-use pretty_assertions::assert_eq;
+use {super::*, crate::compiler::Compiler, pretty_assertions::assert_eq};
 
 pub(crate) fn compile(text: &str) -> Justfile {
   match Compiler::compile(text) {
     Ok(justfile) => justfile,
-    Err(error) => panic!("Expected successful compilation but got error:\n {}", error),
+    Err(error) => panic!("Expected successful compilation but got error:\n {error}"),
   }
 }
 
