@@ -1,6 +1,7 @@
-use super::*;
-
-use std::time::{Duration, Instant};
+use {
+  super::*,
+  std::time::{Duration, Instant},
+};
 
 fn kill(process_id: u32) {
   unsafe {
@@ -16,8 +17,8 @@ fn interrupt_test(arguments: &[&str], justfile: &str) {
 
   let start = Instant::now();
 
-  let mut child = Command::new(&executable_path("just"))
-    .current_dir(&tmp)
+  let mut child = Command::new(executable_path("just"))
+    .current_dir(tmp)
     .args(arguments)
     .spawn()
     .expect("just invocation failed");
