@@ -3,7 +3,7 @@ use super::*;
 fn test(justfile: &str, value: Value) {
   Test::new()
     .justfile(justfile)
-    .args(&["--dump", "--dump-format", "json", "--unstable"])
+    .args(["--dump", "--dump-format", "json", "--unstable"])
     .stdout(format!("{}\n", serde_json::to_string(&value).unwrap()))
     .run();
 }
@@ -709,7 +709,7 @@ fn quiet() {
 fn requires_unstable() {
   Test::new()
     .justfile("foo:")
-    .args(&["--dump", "--dump-format", "json"])
+    .args(["--dump", "--dump-format", "json"])
     .stderr("error: The JSON dump format is currently unstable. Invoke `just` with the `--unstable` flag to enable unstable features.\n")
     .status(EXIT_FAILURE)
     .run();
