@@ -51,6 +51,7 @@ mod fallback;
 mod fmt;
 mod functions;
 mod ignore_comments;
+mod includes;
 mod init;
 #[cfg(unix)]
 mod interrupts;
@@ -72,6 +73,8 @@ mod recursion_limit;
 mod regexes;
 mod run;
 mod search;
+mod search_arguments;
+mod shadowing_parameters;
 mod shebang;
 mod shell;
 mod show;
@@ -91,3 +94,11 @@ fn path(s: &str) -> String {
     s.into()
   }
 }
+
+fn path_for_regex(s: &str) -> String {
+  if cfg!(windows) {
+    s.replace('/', "\\\\")
+  } else {
+    s.into()
+  }
+}
