@@ -47,6 +47,7 @@ pub(crate) struct Test {
   pub(crate) stdout: String,
   pub(crate) stdout_regex: Option<Regex>,
   pub(crate) tempdir: TempDir,
+  pub(crate) test_round_trip: bool,
   pub(crate) unindent_stdout: bool,
 }
 
@@ -69,6 +70,7 @@ impl Test {
       stdout: String::new(),
       stdout_regex: None,
       tempdir,
+      test_round_trip: true,
       unindent_stdout: true,
     }
   }
@@ -125,7 +127,7 @@ impl Test {
   }
 
   pub(crate) fn stderr_regex(mut self, stderr_regex: impl AsRef<str>) -> Self {
-    self.stderr_regex = Some(Regex::new(&format!("(?m)^{}$", stderr_regex.as_ref())).unwrap());
+    self.stderr_regex = Some(Regex::new(&format!("^{}$", stderr_regex.as_ref())).unwrap());
     self
   }
 
@@ -140,7 +142,12 @@ impl Test {
   }
 
   pub(crate) fn stdout_regex(mut self, stdout_regex: impl AsRef<str>) -> Self {
-    self.stdout_regex = Some(Regex::new(&format!("(?m)^{}$", stdout_regex.as_ref())).unwrap());
+    self.stdout_regex = Some(Regex::new(&format!("^{}$", stdout_regex.as_ref())).unwrap());
+    self
+  }
+
+  pub(crate) fn test_round_trip(mut self, test_round_trip: bool) -> Self {
+    self.test_round_trip = test_round_trip;
     self
   }
 
@@ -245,7 +252,7 @@ impl Test {
       panic!("Output mismatch.");
     }
 
-    if self.status == EXIT_SUCCESS {
+    if self.test_round_trip && self.status == EXIT_SUCCESS {
       test_round_trip(self.tempdir.path());
     }
 
